@@ -5,30 +5,36 @@ so we do not need to pass params across functions and models
 import os
 import yaml
 import argparse
+from hashlib import sha256
 from typing import List, Any, Dict
 
 
 CONFIG_ARG_PREFIX = '--config.'
+ALLOWED_LIST_SEPARATORS = [',', ' ', '|', '-']
+ALLOWED_LIST_OPENERS = ['[', '(', '{']
+ALLOWED_LIST_CLOSERS = [']', ')', '}']
 
 
 class Config:
     @classmethod
     def load(cls, config_path: os.PathLike, frozen: bool=True) -> "Config":
         with open(config_path, "r", encoding="utf-8") as config_file:
-            config = Config(yaml.safe_load(config_file), frozen=frozen)
-
-        return config
+            return Config.load_from_string(config_file, frozen=frozen)
 
     @classmethod
-    def read_from_cli(cls, should_infer_type: bool=True) -> "Config":
+    def load_from_string(cls, config_string: str, frozen: bool=True) -> "Config":
+        return Config(yaml.safe_load(config_string), frozen=frozen)
+
+    @classmethod
+    def read_from_cli(cls, should_infer_type: bool=True, config_arg_prefix: str=CONFIG_ARG_PREFIX) -> "Config":
         """Reads config args from the CLI and converts them to a config"""
         _, config_args = argparse.ArgumentParser().parse_known_args()
 
-        # Filtering out those args that do not start with `CONFIG_ARG_PREFIX`
-        config = {c: config_args[i+1] for i, c in enumerate(config_args) if c.startswith(CONFIG_ARG_PREFIX)}
+        # Filtering out those args that do not start with `config_arg_prefix`
+        config = {c: config_args[i+1] for i, c in enumerate(config_args) if c.startswith(config_arg_prefix)}
 
         # Extracting true names (i.e. removing the prefix)
-        config = {c[len(CONFIG_ARG_PREFIX):]: v for c, v in config.items()}
+        config = {c[len(config_arg_prefix):]: v for c, v in config.items()}
 
         if should_infer_type:
             config = {c: infer_type_and_convert(v) for c, v in config.items()}
@@ -78,7 +84,7 @@ class Config:
         return default_value
 
     def __getitem__(self, key: str) -> Any:
-        assert self.has(key)
+        assert self.has(key), f'Key {key} is missing in the config'
 
         return self.get(key)
 
@@ -212,8 +218,11 @@ class Config:
 
         return Config(result, frozen=self.is_frozen)
 
-    def clone(self) -> "Config":
-        return Config(self.to_dict(), frozen=self.is_frozen)
+    def clone(self, frozen: bool=True) -> "Config":
+        return Config(self.to_dict(), frozen=frozen)
+
+    def compute_hash(self, size: int=10) -> str:
+        return sha256(str(self).encode('utf-8')).hexdigest()[:size]
 
 
 def homogenous_array_message(array:List) -> str:
@@ -233,10 +242,33 @@ def infer_type_and_convert(value:str) -> Any:
         return int(value)
     elif is_float(value):
         return float(value)
+    elif is_list(value):
+        if has_list_closers(value): value = value[1:-1]
+
+        separator = next((s for s in ALLOWED_LIST_SEPARATORS if s in value), ',')
+        value = [infer_type_and_convert(x) for x in value.split(separator) if len(x) > 0]
+
+        return value
     else:
         return value
 
 
+def is_list(value: str) -> bool:
+    """A dirty function that checks if the value looks like list"""
+    return is_separated(value) or has_list_closers(value)
+
+
+def is_separated(value: str) -> bool:
+    return any((s in value) for s in ALLOWED_LIST_SEPARATORS)
+
+
+def has_list_closers(value: str) -> bool:
+    try:
+        return (ALLOWED_LIST_OPENERS.index(value[0]) == ALLOWED_LIST_CLOSERS.index(value[-1]))
+    except:
+        return False
+
+
 def is_float(value: Any) -> bool:
     """One more dirty function: it checks if the string is float."""
     try:
